@@ -367,7 +367,7 @@ replCmat4 <- function(x, i1, i2, iMi, jMi, value, spV = is(value,"sparseVector")
 	    ##	     but really could be faster and write something like cs_drop_k(A, k)
 	    ## v0 <- 0 == value
 	    ## if (lenRepl == 1) and v0 is TRUE, the following is not doing anything
-	    ##-	 --> ./dgTMatrix.R	and its	 replTmat()
+	    ##-	 --> ./Tsparse.R	and its	 replTmat()
 	    ## x@x[sel[!v0]] <- value[!v0]
 	    x@x[sel] <- as.vector(value[iN0])
 	    if(extends(clDx, "compMatrix") && length(x@factors)) # drop cashed ones
@@ -515,3 +515,26 @@ setMethod("Cholesky", signature(A = "CsparseMatrix"),
 setMethod("Cholesky", signature(A = "nsparseMatrix"),
 	  function(A, perm = TRUE, LDL = !super, super = FALSE, Imult = 0, ...)
 	  stop("Cholesky(<nsparse...>) -> *symbolic* factorization -- not yet implemented"))
+
+if(FALSE)
+isDiagCsp <- function(object) {
+    d <- dim(object)
+    if((n <- d[1]) != d[2])
+        FALSE
+    else if(n == 0)
+        TRUE
+    else # (n >= 1)
+        ## "FIXME": do this in C  --->>> for now use Csparse_to_Tsparse
+        (m <- length(i <- object@i)) == 0 || {
+            m <= n && !anyDuplicated(i) &&
+                ## length(p <- object@p) == n+1L &&
+                all((dp <- diff(object@p)) <= 1L) &&
+                length(j <- base::which(dp == 1L)) == m && all(j == i+1L)
+        }
+}
+if(FALSE)
+setMethod("isDiagonal", signature(object = "CsparseMatrix"), isDiagCsp)
+
+setMethod("isDiagonal", signature(object = "CsparseMatrix"),
+	  function(object) isDiagTsp(.Call(Csparse_to_Tsparse, object, is(object, "triangularMatrix"))))
+
